package com.ruoyi.tcZz.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.tcZz.domain.TcAqg;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.tcZz.mapper.TcSgjipTop5Mapper;
import com.ruoyi.tcZz.domain.TcSgjipTop5;
import com.ruoyi.tcZz.service.ITcSgjipTop5Service;

/**
 * 受攻击IPTOP5Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-10-12
 */
@Service
public class TcSgjipTop5ServiceImpl implements ITcSgjipTop5Service 
{
    @Autowired
    private TcSgjipTop5Mapper tcSgjipTop5Mapper;

    /**
     * 查询受攻击IPTOP5
     * 
     * @param id 受攻击IPTOP5主键
     * @return 受攻击IPTOP5
     */
    @Override
    public TcSgjipTop5 selectTcSgjipTop5ById(Long id)
    {
        return tcSgjipTop5Mapper.selectTcSgjipTop5ById(id);
    }

    /**
     * 查询受攻击IPTOP5列表
     * 
     * @param tcSgjipTop5 受攻击IPTOP5
     * @return 受攻击IPTOP5
     */
    @Override
    public List<TcSgjipTop5> selectTcSgjipTop5List(TcSgjipTop5 tcSgjipTop5)
    {
        return tcSgjipTop5Mapper.selectTcSgjipTop5List(tcSgjipTop5);
    }

    /**
     * 新增受攻击IPTOP5
     * 
     * @param tcSgjipTop5 受攻击IPTOP5
     * @return 结果
     */
    @Override
    public int insertTcSgjipTop5(TcSgjipTop5 tcSgjipTop5)
    {
        tcSgjipTop5.setCreateTime(DateUtils.getNowDate());
        return tcSgjipTop5Mapper.insertTcSgjipTop5(tcSgjipTop5);
    }

    /**
     * 修改受攻击IPTOP5
     * 
     * @param tcSgjipTop5 受攻击IPTOP5
     * @return 结果
     */
    @Override
    public int updateTcSgjipTop5(TcSgjipTop5 tcSgjipTop5)
    {
        tcSgjipTop5.setUpdateTime(DateUtils.getNowDate());
        return tcSgjipTop5Mapper.updateTcSgjipTop5(tcSgjipTop5);
    }

    /**
     * 批量删除受攻击IPTOP5
     * 
     * @param ids 需要删除的受攻击IPTOP5主键
     * @return 结果
     */
    @Override
    public int deleteTcSgjipTop5ByIds(Long[] ids)
    {
        return tcSgjipTop5Mapper.deleteTcSgjipTop5ByIds(ids);
    }

    /**
     * 删除受攻击IPTOP5信息
     * 
     * @param id 受攻击IPTOP5主键
     * @return 结果
     */
    @Override
    public int deleteTcSgjipTop5ById(Long id)
    {
        return tcSgjipTop5Mapper.deleteTcSgjipTop5ById(id);
    }

    @Override
    public String importUser(List<TcSgjipTop5> tcSgjipTop5List) {
        StringBuilder successMsg = new StringBuilder();
        if (!tcSgjipTop5List.isEmpty()) {
            for (TcSgjipTop5 tcSgjipTop5 : tcSgjipTop5List) {
                tcSgjipTop5Mapper.insertTcSgjipTop5(tcSgjipTop5);
            }
            successMsg.append("导入成功");
        }

        return successMsg.toString();
    }

    @Override
    public void updateByisStatus(Integer isStatus,List<String> ids) {
        tcSgjipTop5Mapper.updateByisStatus(isStatus,ids);
    }
}
