package com.ruoyi.tcZz.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.tcZz.domain.TcAqg;
import com.ruoyi.tcZz.domain.TcSdtb;
import com.ruoyi.tcZz.domain.TcSgjipTop5;
import com.ruoyi.tcZz.service.ITcSgjipTop5Service;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 受攻击IPTOP5Controller
 *
 * @author ruoyi
 * @date 2023-10-12
 */
@RestController
@Api(tags = "受攻击IPTOP5")
@RequestMapping("/tcZz/networkSecurity/top5")
public class TcSgjipTop5Controller extends BaseController {
    @Autowired
    private ITcSgjipTop5Service tcSgjipTop5Service;

    /**
     * 查询受攻击IPTOP5列表
     */
    @ApiOperation(value = "查询受攻击IPTOP5列表", response = TcSgjipTop5.class)
    @GetMapping("/list")
    public TableDataInfo list(TcSgjipTop5 tcSgjipTop5) {
        startPage();
        List<TcSgjipTop5> list = tcSgjipTop5Service.selectTcSgjipTop5List(tcSgjipTop5);
        return getDataTable(list);
    }

    /**
     * 导出受攻击IPTOP5列表
     */
    @ApiOperation(value = "导出受攻击IPTOP5列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcSgjipTop5 tcSgjipTop5) {
        List<TcSgjipTop5> list = tcSgjipTop5Service.selectTcSgjipTop5List(tcSgjipTop5);
        ExcelUtil<TcSgjipTop5> util = new ExcelUtil<TcSgjipTop5>(TcSgjipTop5.class);
        util.exportExcel(response, list, "受攻击IPTOP5数据");
    }

    /**
     * 获取受攻击IPTOP5详细信息
     */
    @ApiOperation(value = "获取受攻击IPTOP5详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcSgjipTop5Service.selectTcSgjipTop5ById(id));
    }

    /**
     * 新增受攻击IPTOP5
     */
    @ApiOperation(value = "新增受攻击IPTOP5")
    @PostMapping
    public AjaxResult add(@RequestBody TcSgjipTop5 tcSgjipTop5) {
        return toAjax(tcSgjipTop5Service.insertTcSgjipTop5(tcSgjipTop5));
    }

    /**
     * 修改受攻击IPTOP5
     */
    @ApiOperation(value = "修改受攻击IPTOP5")
    @PutMapping
    public AjaxResult edit(@RequestBody TcSgjipTop5 tcSgjipTop5) {
        return toAjax(tcSgjipTop5Service.updateTcSgjipTop5(tcSgjipTop5));
    }

    /**
     * 删除受攻击IPTOP5
     */
    @ApiOperation(value = "删除受攻击IPTOP5")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcSgjipTop5Service.deleteTcSgjipTop5ByIds(ids));
    }
    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcSgjipTop5> util = new ExcelUtil<TcSgjipTop5>(TcSgjipTop5.class);
        List<TcSgjipTop5> tcSgjipTop5List = util.importExcel(file.getInputStream());
        tcSgjipTop5Service.importUser(tcSgjipTop5List);
        return AjaxResult.success();
    }

    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcSgjipTop5Service.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcSgjipTop5> util = new ExcelUtil<TcSgjipTop5>(TcSgjipTop5.class);
        util.importTemplateExcel(response, " 受攻击IPTOP5");
    }
}
